==> v0.4.69.tar.gz: submit-social-housing-lettings-and-sales-data/spec/models/form/lettings/questions/joint_spec.rb <==
require "rails_helper"

RSpec.describe Form::Lettings::Questions::Joint, type: :model do
  subject(:question) { described_class.new(question_id, question_definition, page) }

  let(:question_id) { nil }
  let(:question_definition) { nil }
  let(:page) { instance_double(Form::Page) }
  let(:subsection) { instance_double(Form::Subsection) }
  let(:form) { instance_double(Form, start_date: Time.zone.local(2023, 4, 1)) }

  before do
    allow(form).to receive(:start_year_after_2024?).and_return(false)
    allow(page).to receive(:subsection).and_return(subsection)
    allow(subsection).to receive(:form).and_return(form)
  end

  it "has correct page" do
    expect(question.page).to eq(page)
  end

  it "has the correct id" do
    expect(question.id).to eq("joint")
  end

  it "has the correct header" do
    expect(question.header).to eq("Is this a joint tenancy?")
  end

  it "has the correct check_answer_label" do
    expect(question.check_answer_label).to eq("Is this a joint tenancy?")
  end

  it "has the correct type" do
    expect(question.type).to eq("radio")
  end

  it "has the correct hint_text" do
    expect(question.hint_text).to eq("")
  end

  it "has the correct answer_options" do
    expect(question.answer_options).to eq({
      "1" => { "value" => "Yes" },
      "2" => { "value" => "No" },
      "divider" => { "value" => "true" },
      "3" => { "value" => "Don’t know" },
    })
  end

  it "is not marked as derived" do
    expect(question.derived?(nil)).to be false
  end

  context "with collection year on or after 2024" do
    before do
      allow(form).to receive(:start_year_after_2024?).and_return(true)
    end

    it "has the correct hint_text" do
      expect(question.hint_text).to eq("This is where two or more people are named on the tenancy agreement")
    end
  end
end

==> v0.5.0.tar.gz: submit-social-housing-lettings-and-sales-data/spec/models/form/lettings/questions/joint_spec.rb <==
require "rails_helper"

RSpec.describe Form::Lettings::Questions::Joint, type: :model do
  subject(:question) { described_class.new(question_id, question_definition, page) }

  let(:question_id) { nil }
  let(:question_definition) { nil }
  let(:page) { instance_double(Form::Page) }
  let(:subsection) { instance_double(Form::Subsection) }
  let(:form) { instance_double(Form, start_date: Time.zone.local(2023, 4, 1)) }

  before do
    allow(form).to receive(:start_year_2024_or_later?).and_return(false)
    allow(page).to receive(:subsection).and_return(subsection)
    allow(subsection).to receive(:form).and_return(form)
  end

  it "has correct page" do
    expect(question.page).to eq(page)
  end

  it "has the correct id" do
    expect(question.id).to eq("joint")
  end

  it "has the correct type" do
    expect(question.type).to eq("radio")
  end

  it "has the correct answer_options" do
    expect(question.answer_options).to eq({
      "1" => { "value" => "Yes" },
      "2" => { "value" => "No" },
      "divider" => { "value" => "true" },
      "3" => { "value" => "Don’t know" },
    })
  end

  it "is not marked as derived" do
    expect(question.derived?(nil)).to be false
  end

  context "with 2024/25 form" do
    let(:form) { instance_double(Form, start_date: Time.zone.local(2024, 4, 1)) }

    before do
      allow(form).to receive(:start_year_2024_or_later?).and_return(true)
    end

    it "has the correct question number" do
      expect(question.question_number).to eq(25)
    end
  end

  context "with 2025/26 form" do
    let(:form) { instance_double(Form, start_date: Time.zone.local(2025, 4, 1)) }

    before do
      allow(form).to receive(:start_year_2024_or_later?).and_return(true)
    end

    it "has the correct question number" do
      expect(question.question_number).to eq(26)
    end
  end
end
